@@ -8,7 +8,7 @@ use Moo;
 use Mxpress::PDF;
 use Pod::Simpler::Aoh;
 use JSON;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 extends 'MetaCPAN::Client';
 
@@ -110,20 +110,32 @@ sub set_style {
 	$_[0]->styles->{$_[1]}->{$_[2]} = $_[3];
 }
 
+sub raw {
+	my ($self, $name, $string, $stringify) = @_;
+	my $pod = Pod::Simpler::Aoh->new->parse_string_document(
+		$string
+	);
+	my $pdf = $self->_start_pdf($name);
+	for my $section (@{$pod}) {
+		$self->_add_pod_to_pdf($pdf, $section);
+	}
+	return $stringify ? $pdf->stringify() : $pdf->save();
+}
+
 sub pdf {
-	my ($self, $module) = @_;
+	my ($self, $module, $stringify) = @_;
 	my $pod = Pod::Simpler::Aoh->new->parse_string_document(
 		$self->pod($module)->x_pod
 	);
 	my $pdf = $self->_start_pdf($module);
 	for my $section (@{$pod}) {
-		$self->add_pod_to_pdf($pdf, $section);
+		$self->_add_pod_to_pdf($pdf, $section);
 	}
-	$pdf->save();
+	return $stringify ? $pdf->stringify() : $pdf->save();
 }
 
 sub dist_pdf {
-	my ($self, $dist) = @_;
+	my ($self, $dist, $stringify) = @_;
 	$dist =~ s/\:\:/-/g;
 	my $release = $self->release($dist);
 	my $pdf = $self->_start_pdf($dist);
@@ -140,8 +152,7 @@ sub dist_pdf {
 		);
 		$self->_add_pod_to_pdf($pdf, $_) for @{$pod};
 	}
-	$pdf->save();
-	return 1;
+	return $stringify ? $pdf->stringify() : $pdf->save();
 }
 
 sub _start_pdf {
@@ -194,7 +205,7 @@ MetaCPAN::Client::Pod::PDF - The great new MetaCPAN::Client::Pod::PDF!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -308,6 +319,8 @@ Generate a PDF for a individual module.
 
 	$pdf->pdf('DBIx::Class');
 
+	my $stringify = $pdf->pdf('DBIx::Class', 1);
+
 =cut
 
 =head2 dist_pdf
@@ -315,6 +328,22 @@ Generate a PDF for a individual module.
 Generate a PDF for a distribution.
 
 	$pdf->dist_pdf('DBIx::Class');
+	
+	my $stringify = $pdf->dist_pdf('DBIx::Class', 1);
+
+=head2 raw
+
+Generate a PDF from raw pod markup.
+
+	my $pod = q|=head1 title
+
+	picture yourself on a boat on a river.
+
+	|;
+
+	$pdf->raw('FileName', $pod);
+	
+	$pdf->raw('FileName', $pod, 1);
 
 =cut
 
